@@ -74,19 +74,19 @@ Dialog::Dialog(QWidget *parent) :
     setWindowTitle(QSL("LXQt Runner"));
     setAttribute(Qt::WA_TranslucentBackground);
 
-    connect(LXQt::Settings::globalSettings(), SIGNAL(iconThemeChanged()), this, SLOT(update()));
-    connect(ui->closeButton, SIGNAL(clicked()), this, SLOT(hide()));
-    connect(mSettings, SIGNAL(settingsChanged()), this, SLOT(applySettings()));
+    connect(LXQt::Settings::globalSettings(), &LXQt::GlobalSettings::iconThemeChanged, this, qOverload<>(&Dialog::update));
+    connect(ui->closeButton, &QToolButton::clicked, this, &Dialog::hide);
+    connect(mSettings, &LXQt::Settings::settingsChanged, this, &Dialog::applySettings);
 
     mSearchTimer.setSingleShot(true);
     connect(&mSearchTimer, &QTimer::timeout, ui->commandEd, [this] {
         setFilter(ui->commandEd->text());
     });
-    mSearchTimer.setInterval(350); // typing speed (not very fast)
+    mSearchTimer.setInterval(250); // typing speed (not very fast)
 
     ui->commandEd->installEventFilter(this);
 
-    connect(ui->commandEd, &QLineEdit::textChanged, [this] (QString const &) {
+    connect(ui->commandEd, &QLineEdit::textChanged, this, [this] (QString const &) {
         mSearchTimer.start();
     });
     connect(ui->commandEd, &QLineEdit::returnPressed, this, &Dialog::runCommand);
@@ -95,7 +95,7 @@ Dialog::Dialog(QWidget *parent) :
     ui->commandList->installEventFilter(this);
     ui->commandList->setModel(mCommandItemModel);
     ui->commandList->setEditTriggers(QAbstractItemView::NoEditTriggers);
-    connect(ui->commandList, SIGNAL(clicked(QModelIndex)), this, SLOT(runCommand()));
+    connect(ui->commandList, &MyListView::clicked, this, &Dialog::runCommand);
     setFilter(QString());
     dataChanged();
 
@@ -229,6 +229,7 @@ bool Dialog::editKeyPressEvent(QKeyEvent *event)
 
     case Qt::Key_Up:
     case Qt::Key_PageUp:
+    case Qt::Key_Home:
         if (ui->commandEd->text().isEmpty() &&
             ui->commandList->isVisible() &&
             ui->commandList->currentIndex().row() == 0
@@ -242,6 +243,7 @@ bool Dialog::editKeyPressEvent(QKeyEvent *event)
 
     case Qt::Key_Down:
     case Qt::Key_PageDown:
+    case Qt::Key_End:
         if (ui->commandEd->text().isEmpty() &&
             ui->commandList->isHidden()
            )
@@ -321,6 +323,7 @@ void Dialog::showHide()
         show();
         KWindowSystem::forceActiveWindow(winId());
         ui->commandEd->setFocus();
+        ui->commandEd->selectAll();
     }
 }
 
@@ -464,7 +467,10 @@ void Dialog::dataChanged()
 {
     if (mCommandItemModel->rowCount())
     {
-       ui->commandList->setCurrentIndex(mCommandItemModel->appropriateItem(mCommandItemModel->command()));
+        // set the current item if not existing
+        if(!ui->commandList->currentIndex().isValid())
+            ui->commandList->setCurrentIndex(mCommandItemModel->appropriateItem(mCommandItemModel->command()));
+        // show the list if it's hidden and scroll to the current item
         ui->commandList->scrollTo(ui->commandList->currentIndex());
         ui->commandList->show();
     }
@@ -492,7 +498,8 @@ void Dialog::runCommand()
     if (res)
     {
         hide();
-        ui->commandEd->clear();
+        if (!qobject_cast<const MathItem*>(command)) // don't clear math results
+            ui->commandEd->clear();
     }
 
 }
