@@ -110,9 +110,9 @@
         <translation>Ιστορικό</translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="845"/>
-        <source>Mathematics</source>
-        <translation>Μαθηματικά</translation>
+        <location filename="../providers.cpp" line="846"/>
+        <source>Copy calculation result to clipboard</source>
+        <translation>Αντιγραφή του αποτελέσματος υπολογισμού στο πρόχειρο</translation>
     </message>
 </context>
 </TS>
