@@ -6,7 +6,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="14"/>
         <source>Runner Settings</source>
-        <translation>Paramétrage de lxqt-runner</translation>
+        <translation>Paramétres de lxqt-runner</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="20"/>
@@ -21,7 +21,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="36"/>
         <source>Show on:</source>
-        <translation>Montrer au :</translation>
+        <translation>Afficher sur :</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="46"/>
@@ -36,7 +36,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="60"/>
         <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
-        <translation>&lt;b&gt;Note&lt;/b&gt;: La taille des widgets de niveau supérieur est limitée à 2/3 de la hauteur et de la largeur du bureau.</translation>
+        <translation>&lt;b&gt;Note&lt;/b&gt; : La taille des widgets de niveau supérieur est limitée à 2/3 de la hauteur et de la largeur du bureau.</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="63"/>
@@ -110,9 +110,9 @@
         <translation>Historique</translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="845"/>
-        <source>Mathematics</source>
-        <translation>Mathématiques</translation>
+        <location filename="../providers.cpp" line="846"/>
+        <source>Copy calculation result to clipboard</source>
+        <translation>Copier le résultat du calcul vers le presse-papier</translation>
     </message>
 </context>
 </TS>
