@@ -110,9 +110,9 @@
         <translation>היסטוריה</translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="845"/>
-        <source>Mathematics</source>
-        <translation>מתמטיקה</translation>
+        <location filename="../providers.cpp" line="846"/>
+        <source>Copy calculation result to clipboard</source>
+        <translation>העתקת תוצאות החישוב ללוח הגזירים</translation>
     </message>
 </context>
 </TS>
