@@ -110,9 +110,9 @@
         <translation>Historikk</translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="845"/>
-        <source>Mathematics</source>
-        <translation>Mattematikk</translation>
+        <location filename="../providers.cpp" line="846"/>
+        <source>Copy calculation result to clipboard</source>
+        <translation>Kopier utregnet resultat til utklippstavlen</translation>
     </message>
 </context>
 </TS>
