@@ -110,9 +110,9 @@
         <translation>Histórico</translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="845"/>
-        <source>Mathematics</source>
-        <translation>Matemática</translation>
+        <location filename="../providers.cpp" line="846"/>
+        <source>Copy calculation result to clipboard</source>
+        <translation>Copiar o resultado do cálculo para a área de transferência</translation>
     </message>
 </context>
 </TS>
