@@ -110,8 +110,8 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../providers.cpp" line="845"/>
-        <source>Mathematics</source>
+        <location filename="../providers.cpp" line="846"/>
+        <source>Copy calculation result to clipboard</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
